==> camel-aws2-ecs-3.2.0-sources.jar: org/apache/camel/component/aws2/ecs/ECS2Component.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ecs;

import java.util.Map;
import java.util.Set;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.DefaultComponent;
import org.apache.camel.util.ObjectHelper;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import software.amazon.awssdk.services.ecs.EcsClient;

/**
 * For working with Amazon ECS SDK v2.
 */
@Component("aws2-ecs")
public class ECS2Component extends DefaultComponent {

    private static final Logger LOG = LoggerFactory.getLogger(ECS2Component.class);
    
    @Metadata
    private ECS2Configuration configuration = new ECS2Configuration();

    public ECS2Component() {
        this(null);
    }

    public ECS2Component(CamelContext context) {
        super(context);

        registerExtension(new ECS2ComponentVerifierExtension());
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        ECS2Configuration configuration = this.configuration != null ? this.configuration.copy() : new ECS2Configuration();
        ECS2Endpoint endpoint = new ECS2Endpoint(uri, this, configuration);
        setProperties(endpoint, parameters);
        checkAndSetRegistryClient(configuration, endpoint);
        if (configuration.getEcsClient() == null && (configuration.getAccessKey() == null || configuration.getSecretKey() == null)) {
            throw new IllegalArgumentException("Amazon ecs client or accessKey and secretKey must be specified");
        }

        return endpoint;
    }

    public ECS2Configuration getConfiguration() {
        return configuration;
    }

    /**
     * Component configuration
     */
    public void setConfiguration(ECS2Configuration configuration) {
        this.configuration = configuration;
    }

    private void checkAndSetRegistryClient(ECS2Configuration configuration, ECS2Endpoint endpoint) {
        if (ObjectHelper.isEmpty(endpoint.getConfiguration().getEcsClient())) {
            LOG.debug("Looking for an EcsClient instance in the registry");
            Set<EcsClient> clients = getCamelContext().getRegistry().findByType(EcsClient.class);
            if (clients.size() == 1) {
                LOG.debug("Found exactly one EcsClient instance in the registry");
                configuration.setEcsClient(clients.stream().findFirst().get());
            } else {
                LOG.debug("No EcsClient instance in the registry");
            }
        } else {
            LOG.debug("EcsClient instance is already set at endpoint level: skipping the check in the registry");
        }
    }
}

==> camel-aws2-ecs-4.0.0-sources.jar: org/apache/camel/component/aws2/ecs/ECS2Component.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.aws2.ecs;

import java.util.Map;

import org.apache.camel.CamelContext;
import org.apache.camel.Endpoint;
import org.apache.camel.spi.Metadata;
import org.apache.camel.spi.annotations.Component;
import org.apache.camel.support.HealthCheckComponent;

/**
 * For working with Amazon ECS SDK v2.
 */
@Component("aws2-ecs")
public class ECS2Component extends HealthCheckComponent {

    @Metadata
    private ECS2Configuration configuration = new ECS2Configuration();

    public ECS2Component() {
        this(null);
    }

    public ECS2Component(CamelContext context) {
        super(context);
    }

    @Override
    protected Endpoint createEndpoint(String uri, String remaining, Map<String, Object> parameters) throws Exception {
        ECS2Configuration configuration = this.configuration != null ? this.configuration.copy() : new ECS2Configuration();
        ECS2Endpoint endpoint = new ECS2Endpoint(uri, this, configuration);
        setProperties(endpoint, parameters);
        if (Boolean.FALSE.equals(configuration.isUseDefaultCredentialsProvider())
                && Boolean.FALSE.equals(configuration.isUseProfileCredentialsProvider()) && configuration.getEcsClient() == null
                && (configuration.getAccessKey() == null || configuration.getSecretKey() == null)) {
            throw new IllegalArgumentException(
                    "useDefaultCredentialsProvider is set to false, useProfileCredentialsProvider is set to false, Amazon ecs client or accessKey and secretKey must be specified");
        }

        return endpoint;
    }

    public ECS2Configuration getConfiguration() {
        return configuration;
    }

    /**
     * Component configuration
     */
    public void setConfiguration(ECS2Configuration configuration) {
        this.configuration = configuration;
    }
}
